package main;

import java.util.ArrayList;
import java.util.Collections;

public class Highway {
	private final static double MORNING_TRAVEL_TIME_AVG = 1.35;
	private final static double MORNING_TRAVEL_TIME_95 = 1.80;
	private final static double EVENING_TRAVEL_TIME_AVG = 1.45;
	private final static double EVENING_TRAVEL_TIME_95 = 2.03;
	private final static double STATONARY_EMISSION_PERCENTAGE = 0.25;
	
	private boolean morning;
	private double travelTimel;
	private double percentageOnTheRoad;
	
	private ArrayList<Worker> todaysCommuters;
	
	public Highway(ArrayList<Worker> todaysCommuters, int workforce, boolean morning){
		this.todaysCommuters = todaysCommuters;
		
		this.percentageOnTheRoad = (this.todaysCommuters.size()*1.0/workforce);
		this.morning = morning;
		travelTimel = travelTime();
		
		for (Worker worker : todaysCommuters) {
			commuteTrip(worker);
		}
	}
	
	public void commuteTrip(Worker worker){
		Car car = worker.getCar();
		double co2GramPerKm = car.getCo2GramPerKm();
		double distanceToOffice = worker.getHome().getDistanceToOffice();
		
		double commuteCo2e = co2GramPerKm*distanceToOffice;
		
		double congestionCo2e = commuteCo2e*(1.5-1.0)*STATONARY_EMISSION_PERCENTAGE - commuteCo2e*(travelTimel-1.0)*STATONARY_EMISSION_PERCENTAGE;
		commuteCo2e += commuteCo2e*(travelTimel-1.0)*STATONARY_EMISSION_PERCENTAGE;
		
		car.getEmission().incrementCo2e(commuteCo2e);
		car.getEmission().co2eCommuting += commuteCo2e;
		car.getEmission().co2eCongestion += congestionCo2e;
	
		if(worker.getHome().getHasMoved()){
			double extraDistance = 0.0;
			extraDistance = distanceToOffice-(distanceToOffice/1.834);
			
			double resRelCo2e = co2GramPerKm*extraDistance;
			resRelCo2e += resRelCo2e*(travelTimel-1.0)*STATONARY_EMISSION_PERCENTAGE;
			car.getEmission().co2eResidentialRelocation += resRelCo2e;
		}
	}
	
	public double travelTime(){
		double avg;
		double percentile;
		double eq;
		if (morning){
			avg = MORNING_TRAVEL_TIME_AVG;
			percentile = MORNING_TRAVEL_TIME_95;
		}
		else {
			avg = EVENING_TRAVEL_TIME_AVG;
			percentile = EVENING_TRAVEL_TIME_95;
		}
		eq = Math.exp((1/avg));
		eq *= percentile;
		return 1.5-(1-percentageOnTheRoad);
	}
}