package main;

public class Home extends Building {
	
	private static final double YEARLY_BTU_AVG = 62000000;
	private static final double AVG_HOUSE_SIZE_FT2 = 1580;
	private static final double AVG_HOUSE_SIZE_M2 = 146.8;
	private static final double NG_CONSUMPTION_PERCENTAGE = .78;
	private static final double EL_CONSUMPTION_PERCETANGE = 1-NG_CONSUMPTION_PERCENTAGE;
	
	private Worker worker;
	private double distanceToOffice;
	private double dailyCo2e;
	private boolean lightbulbs;
	private boolean hasMoved;
	
	private double yearlyConsumptionBtu;
	
	public Home (Worker worker){
		this.worker = worker;
		distanceToOffice = (Start.random.nextGaussian()*5 + 19);
		yearlyConsumption();
		lightbulbs = Start.random.nextBoolean();
	}
	
	public double getDistanceToOffice(){
		return distanceToOffice;
	}
	
	public void setDistanceToOffice(double distanceToOffice){
		this.distanceToOffice = distanceToOffice;
	}
	
	public void yearlyConsumption(){
		yearlyConsumptionBtu = YEARLY_BTU_AVG;
		
	}
	
	public void setHasMoved(boolean hasMoved){
		this.hasMoved = hasMoved;
	}
	
	public boolean getHasMoved(){
		return hasMoved;
	}
	
	public void dailyConsumption(boolean weekend, Month month){
		emission = new Emission();
		double avgDailyConsumptionBtuEl = (yearlyConsumptionBtu*EL_CONSUMPTION_PERCETANGE)/365;
		double avgDailyConsumptionBtuNG = (yearlyConsumptionBtu*NG_CONSUMPTION_PERCENTAGE)/365;
		
		double seasonalMultiplier = month.getSeasonalMultipler();
		double todaysTemperatureModifier = month.todaysTemperatureModifier();
		avgDailyConsumptionBtuEl = avgDailyConsumptionBtuEl*seasonalMultiplier*todaysTemperatureModifier;
		avgDailyConsumptionBtuNG = avgDailyConsumptionBtuNG*seasonalMultiplier*todaysTemperatureModifier;
		
		double avgDailyCo2eNG = emission.ngBtuToCo2e(avgDailyConsumptionBtuNG);
		double avgDailyCo2eEl = emission.elKwhToCo2e(emission.btuToKwh(avgDailyConsumptionBtuEl));
		
		double co2e = avgDailyCo2eEl + avgDailyCo2eNG;
		
		dailyCo2e = co2e;
		emission.incrementCo2e(co2e);
	}
	
	public void equipPhone(){
		double phoneCo2e = (Start.random.nextGaussian()*4 + 60) * 1000;
		worker.getEmission().incrementCo2e(phoneCo2e);
		worker.getEmission().co2ePersonalDevices += phoneCo2e;
	}
	
	public void equipComputer(){
		double computerCo2 = (Start.random.nextGaussian()*90 + 500) * 1000;
		worker.getEmission().incrementCo2e(computerCo2);
		worker.getEmission().co2ePersonalDevices += computerCo2;
	}
	
	public void homeOffice(boolean weekend, Month month){
		double officeCo2e = dailyCo2e * 0.31 * 0.25 * 0.50;
		worker.getEmission().incrementCo2e(officeCo2e);
		// LIGHTING
		
		double lightingCo2e;
		if(lightbulbs){
			lightingCo2e = emission.elKwhToCo2e(2.4);
		}
		else{
			lightingCo2e = emission.elKwhToCo2e(0.54);
		}
		worker.getEmission().incrementCo2e(lightingCo2e);
		worker.getEmission().co2eHomeOffice = officeCo2e + lightingCo2e;
	}
	
	public void generalUsageOfElectricity(){
		double generalCo2e = emission.elKwhToCo2e(10);
		worker.getEmission().incrementCo2e(generalCo2e);
		worker.getEmission().co2eHomeGeneralEl = generalCo2e;
	}
}
