package main;

import java.io.FileWriter;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.GregorianCalendar;

public class Log {
	
	ArrayList<Worker> workers;
	ArrayList<Worker> telecommuters;
	ArrayList<Worker> commuters;
	ArrayList<Office> offices;
	ArrayList<Emission> emissions;
	ArrayList<EmissionData> emissionData;
	
	
	public Log(ArrayList<Worker> workers) {
		this.workers = workers;
	}
	public void setEmissions(ArrayList<Emission> emissions){
		this.emissions = emissions;
	}
	
	public void dailyCo2e(){
		try
		{
		    String filename= "dailyCo2e.csv";
		    FileWriter fw = new FileWriter(filename, true); //the true will append the new data
		    fw.write("Date, Worker, Home, Office, Commuting\n");
		    for (EmissionData ed : emissionData) {
		    	fw.write(ed.workerEmission.getDate() + ", " + ed.workerEmission.getCo2e() + ", " + ed.homeEmission.getCo2e() + ", " + ed.officeEmission.getCo2e() +
		    			", " + ed.carEmission.getCo2e() + "\n");
			}
		    fw.close();
		}
		catch(IOException ioe)
		{
		    System.err.println("IOException: " + ioe.getMessage());
		}
	}
	
	public void monthlyCo2e(){
		try
		{
		    String filename= "monthlyCo2e.csv";
		    FileWriter fw = new FileWriter(filename, true); //the true will append the new data
		    fw.write("Date, Worker, Home, Office, Commuting\n");
		    double worker = 0.0;
		    double home = 0.0;
		    double office = 0.0;
		    double car = 0.0;
		    
		    String month = "01";
		    for (EmissionData ed : emissionData) {
		    	String date = ed.workerEmission.getDate();
		    	String[] array = date.split("-");
		    	String currentMonth = array[1];
		    	
		    	worker += ed.workerEmission.getCo2e();
		    	home += ed.homeEmission.getCo2e();
		    	office += ed.officeEmission.getCo2e();
		    	car += ed.carEmission.getCo2e();
		    	if (!month.equals(currentMonth)){
		    		month = currentMonth;
		    		fw.write(ed.workerEmission.getDate() + ", " + worker + ", " + home + ", " + office +
			    			", " + car + "\n");
		    		worker = 0.0;
				    home = 0.0;
				    office = 0.0;
				    car = 0.0;
		    	}
			}
		    fw.close();
		}
		catch(IOException ioe)
		{
		    System.err.println("IOException: " + ioe.getMessage());
		}
	}
	
	public void yearlyCo2e(){
		try
		{
		    String filename= "yearlyCo2e.csv";
		    FileWriter fw = new FileWriter(filename, true); //the true will append the new data
		    fw.write("Date, Worker, Home, Office, Commuting\n");
		    int counter = 0;
		    double worker = 0.0;
		    double home = 0.0;
		    double office = 0.0;
		    double car = 0.0;
		    for (EmissionData ed : emissionData) {
		    	worker += ed.workerEmission.getCo2e();
		    	home += ed.homeEmission.getCo2e();
		    	office += ed.officeEmission.getCo2e();
		    	car += ed.carEmission.getCo2e();
		    	if (counter == 364){
		    		fw.write(ed.workerEmission.getDate() + ", " + worker + ", " + home + ", " + office +
			    			", " + car + "\n");
		    		worker = 0.0;
				    home = 0.0;
				    office = 0.0;
				    car = 0.0;
				    counter = 0;
		    	}
		    	counter++;
			}
		    fw.close();
		}
		catch(IOException ioe)
		{
		    System.err.println("IOException: " + ioe.getMessage());
		}
	}
	
	public void weeklyCo2e(){
		SimpleDateFormat formatter = new SimpleDateFormat("dd-MM-yyyy");
		Date date = new Date();
		
		double monday = 0.0;
		double tuesday = 0.0;
		double wedensday = 0.0;
		double thursday = 0.0;
		double friday = 0.0;
		double saturday = 0.0;
		double sunday = 0.0;
		
		try
		{
			String filename= "weeklyCo2e.csv";
		    FileWriter fw = new FileWriter(filename, true); //the true will append the new data
		    fw.write("Monday, Tuesday, Wedensday, Thursday, Friday, Saturday, Sunday\n");
		    for (EmissionData ed : emissionData) {
		    	
		    	String dateString = ed.workerEmission.getDate();
		    	try {
					date = (Date) formatter.parse(dateString);
				} catch (ParseException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
		    	int day = date.getDay();
		    	double co2e = ed.workerEmission.getCo2e() + ed.homeEmission.getCo2e() +
		    			ed.officeEmission.getCo2e() + ed.carEmission.getCo2e();
		    	
		    	switch (day) {
				case 0:
					monday += co2e;
					break;
				case 1:
					tuesday += co2e;
					break;
				case 2:
					wedensday += co2e;
					break;
				case 3:
					thursday += co2e;
					break;
				case 4:
					friday += co2e;
					break;
				case 5:
					saturday += co2e;
					break;
				case 6:
					sunday += co2e;
					
					fw.write(monday + ", " + tuesday + ", " + wedensday + ", " + thursday +
			    			", " + friday + ", " + saturday + ", " + sunday + "\n");
					
					monday = 0.0;
					tuesday = 0.0;
					wedensday = 0.0;
					thursday = 0.0;
					friday = 0.0;
					saturday = 0.0;
					sunday = 0.0;
					break;
				default:
					break;
				}
			}
		    
		    fw.close();
		}
		catch(IOException ioe)
		{
		    System.err.println("IOException: " + ioe.getMessage());
		}
	}
	
	public void reboundBlocksCo2e(){
		try
		{
		    String filename= "reboundBlocks.csv";
		    FileWriter fw = new FileWriter(filename, true); //the true will append the new data
		    fw.write("Date, Commuting, Home Office, Devices, Home El, Office Savings, Relocation, Car Avail, Congestion\n");
		    int counter = 0;
		    
			double co2eHomeOffice = 0.0; //worker
			double co2ePersonalDevices = 0.0; //worker
			double co2eHomeGeneralEl = 0.0; //worker
			double co2eOffice = 0.0; //office
			double co2eResidentialRelocation = 0.0; //car
			double co2eCommuting = 0.0; //car
			double co2eCarAvail = 0.0; //worker
			double co2eCongestion = 0.0; //car
		    
		    double worker = 0.0;
		    double home = 0.0;
		    double office = 0.0;
		    double car = 0.0;
		    for (EmissionData ed : emissionData) {
		    	worker += ed.workerEmission.getCo2e();
		    	home += ed.homeEmission.getCo2e();
		    	office += ed.officeEmission.getCo2e();
		    	car += ed.carEmission.getCo2e();
		    	
		    	co2eHomeOffice += ed.workerEmission.co2eHomeOffice; //worker
				co2ePersonalDevices += ed.workerEmission.co2ePersonalDevices; //worker
				co2eHomeGeneralEl += ed.workerEmission.co2eHomeGeneralEl; //worker
				co2eOffice += ed.officeEmission.co2eOffice; //office
				co2eResidentialRelocation += ed.carEmission.co2eResidentialRelocation; //car
				co2eCommuting += ed.carEmission.co2eCommuting; //car
				co2eCarAvail += ed.workerEmission.co2eCarAvail; //worker
				co2eCongestion += ed.carEmission.co2eCongestion; //car
		    	
		    	if (counter == 364){
		    		fw.write(ed.workerEmission.getDate() + ", " + co2eCommuting + ", " + co2eHomeOffice + ", " + co2ePersonalDevices +
			    			", " + co2eHomeGeneralEl + ", " + co2eOffice + ", " + co2eResidentialRelocation + ", " + co2eCarAvail + ", " + co2eCongestion +"\n");
		    		worker = 0.0;
				    home = 0.0;
				    office = 0.0;
				    car = 0.0;
					co2eHomeOffice = 0.0; //worker
					co2ePersonalDevices = 0.0; //worker
					co2eHomeGeneralEl = 0.0; //worker
					co2eOffice = 0.0; //office
					co2eResidentialRelocation = 0.0; //car
					co2eCommuting = 0.0; //car
					co2eCarAvail = 0.0; //worker
					co2eCongestion = 0.0;
				    counter = 0;
		    	}
		    	counter++;
			}
		    fw.close();
		}
		catch(IOException ioe)
		{
		    System.err.println("IOException: " + ioe.getMessage());
		}
	}
	
//	public void dailyCo2e(){
//		try
//		{
//		    String filename= "dailyCo2e.csv";
//		    FileWriter fw = new FileWriter(filename, true); //the true will append the new data
//		    for (Emission emission : emissions) {
//		    	fw.write(emission.getDate() + ", " + emission.getCo2e() + "\n");
//			}
//		    fw.close();
//		}
//		catch(IOException ioe)
//		{
//		    System.err.println("IOException: " + ioe.getMessage());
//		}
//	}

}
