package main;

import java.util.ArrayList;

public class Office extends Building {
	
	private static final double EMPLOYEE_PER_M2 = 18.52;
	private static final double EMPLOYEE_PER_FT2 = 200;
	
	private static final double SMALL_OFFICE_EL_KWH_FT2 = 13.10;
	private static final double SMALL_OFFICE_NG_KBTU_FT2 = 10.54;
	private static final double LARGE_OFFICE_EL_KWH_FT2 = 17.70;
	private static final double LARGE_OFFICE_NG_KBTU_FT2 = 21.93;
	
	private ArrayList<Worker> employees;
	private ArrayList<Worker> telecommuters;
	private int numberOfEmployees;
	private int numberOfEmployeesOffice;
	
	private double yearlyConsumptionKwh;
	private double yearlyConsumptionBtu;
	
	public Office() {
		super();
		employees = new ArrayList<Worker>();
		telecommuters = new ArrayList<Worker>();
		numberOfEmployees();
		numberOfEmployeesOffice = numberOfEmployees;
		m2 = EMPLOYEE_PER_M2*numberOfEmployees;
	}

	public void addEmployee(Worker employee){
		employees.add(employee);
	}
	
	public void addTelecommuter(Worker telecommuter){
		telecommuters.add(telecommuter);
	}
	
	public int getNumberOfEmployees(){
		return numberOfEmployees;
	}
	
	public void numberOfEmployees(){
		numberOfEmployees = (int) (Start.random.nextGaussian()*50 + 100);
	}
	
	public void flexibleOffice(){
		int[] days = {0, 0, 0, 0, 0};
		for (Worker worker : telecommuters) {
			boolean[] tcDays = worker.getTcDays();
			int day = 0;
			for (boolean tcDay : tcDays) {
				if(tcDay){
					days[day]++;
				}
				day++;
			}
		}
		
		boolean zero = false;
		int peopleReduction = 0;
		while(!zero){
			for (int i = 0; i <= 4; i++) {
				if(days[i] == 0){
					zero = true;
					break;
				}
				days[i]--;
			}
			peopleReduction++;
		}
		numberOfEmployeesOffice = numberOfEmployees - peopleReduction;
		m2 = numberOfEmployeesOffice * EMPLOYEE_PER_M2;
	}
	
	public void yearlyConsumption(){
		if(numberOfEmployeesOffice < 150){
			yearlyConsumptionKwh = SMALL_OFFICE_EL_KWH_FT2 * (EMPLOYEE_PER_FT2 * numberOfEmployeesOffice);
			yearlyConsumptionBtu = SMALL_OFFICE_NG_KBTU_FT2 * (EMPLOYEE_PER_FT2 * numberOfEmployeesOffice) * 1000;
		}
		else {
			yearlyConsumptionKwh = LARGE_OFFICE_EL_KWH_FT2 * (EMPLOYEE_PER_FT2 * numberOfEmployeesOffice);
			yearlyConsumptionBtu = LARGE_OFFICE_NG_KBTU_FT2 * (EMPLOYEE_PER_FT2 * numberOfEmployeesOffice) * 1000;
		}
	}
	
	public void dailyConsumption(boolean weekend, Month month){
		double avgDailyConsumptionKwh = yearlyConsumptionKwh/365;
		double avgDailyConsumptionBtu = yearlyConsumptionBtu/365;
		
		double dailyConsumptionKwh;
		double dailyConsumptionBtu;
		double seasonalMultiplier = month.getSeasonalMultipler();
		
		dailyConsumptionKwh = avgDailyConsumptionKwh*seasonalMultiplier;
		dailyConsumptionBtu = avgDailyConsumptionBtu*seasonalMultiplier;
		if(weekend){
			dailyConsumptionKwh = dailyConsumptionKwh*.50;
			dailyConsumptionBtu = dailyConsumptionBtu*.50;
		}
		else {
			double todaysTemperatureModifier = month.todaysTemperatureModifier();
			dailyConsumptionKwh = dailyConsumptionKwh*todaysTemperatureModifier;
			dailyConsumptionBtu = dailyConsumptionBtu*todaysTemperatureModifier;
		}
		
		emission = new Emission();
		double co2e = emission.elKwhToCo2e(dailyConsumptionKwh);
		co2e += emission.ngBtuToCo2e(dailyConsumptionBtu);
		emission.incrementCo2e(co2e);
		
		double newOrig = originalDailyCo2e(weekend, month, numberOfEmployees);
		emission.co2eOffice = newOrig-co2e;
	}
	
	public double originalDailyCo2e(boolean weekend, Month month, int emp){
		double yearlyConsumptionKwh;
		double yearlyConsumptionBtu;
		if(emp < 150){
			yearlyConsumptionKwh = SMALL_OFFICE_EL_KWH_FT2 * (EMPLOYEE_PER_FT2 * emp);
			yearlyConsumptionBtu = SMALL_OFFICE_NG_KBTU_FT2 * (EMPLOYEE_PER_FT2 * emp) * 1000;
		}
		else {
			yearlyConsumptionKwh = LARGE_OFFICE_EL_KWH_FT2 * (EMPLOYEE_PER_FT2 * emp);
			yearlyConsumptionBtu = LARGE_OFFICE_NG_KBTU_FT2 * (EMPLOYEE_PER_FT2 * emp) * 1000;
		}
		
		double avgDailyConsumptionKwh = yearlyConsumptionKwh/365;
		double avgDailyConsumptionBtu = yearlyConsumptionBtu/365;
		
		double dailyConsumptionKwh;
		double dailyConsumptionBtu;
		double seasonalMultiplier = month.getSeasonalMultipler();
		
		dailyConsumptionKwh = avgDailyConsumptionKwh*seasonalMultiplier;
		dailyConsumptionBtu = avgDailyConsumptionBtu*seasonalMultiplier;
		if(weekend){
			dailyConsumptionKwh = dailyConsumptionKwh*.50;
			dailyConsumptionBtu = dailyConsumptionBtu*.50;
		}
		else {
			double todaysTemperatureModifier = month.todaysTemperatureModifier();
			dailyConsumptionKwh = dailyConsumptionKwh*todaysTemperatureModifier;
			dailyConsumptionBtu = dailyConsumptionBtu*todaysTemperatureModifier;
		}
		
		double co2e = emission.elKwhToCo2e(dailyConsumptionKwh);
		co2e += emission.ngBtuToCo2e(dailyConsumptionBtu);
		return co2e;
	}
	
	public String toString(){
		return super.toString() + ", nrEO: " + numberOfEmployeesOffice  + ", " +  yearlyConsumptionKwh + ", " + yearlyConsumptionBtu;
	}
}
